@@ -1,7 +1,3 @@
-test_that("grep_search - invalid args", {
-  expect_error(grep_search(list()), "Invalid arguments for GrepSearch")
-})
-
 test_that("grep_search - found file", {
   local_mocked_bindings(
     getActiveProject = function(...) tempdir(),
@@ -9,7 +5,7 @@ test_that("grep_search - found file", {
   )
   mock_file <- tempfile(fileext = ".R")
   writeLines("FILE_CONTENT", mock_file)
-  expect_true(grepl("1:FILE_CONTENT", grep_search(list(query = "CONTENT"))$output))
+  expect_true(grepl("1:FILE_CONTENT", grep_search("CONTENT")$output))
 })
 
 test_that("grep_search - not found file", {
@@ -18,5 +14,5 @@ test_that("grep_search - not found file", {
     .package = "myownrobs"
   )
   writeLines("FILE_CONTENT", tempfile(fileext = ".R"))
-  expect_equal(grep_search(list(query = "OTHER_STUFF"))$output, "")
+  expect_equal(grep_search("OTHER_STUFF")$output, "")
 })
